pub struct BoundedCount {
pub count: u64,
pub cap: u64,
pub saturated: bool,
}Expand description
A count whose work and reported value are bounded by an explicit cap.
saturated distinguishes an exact count equal to cap from a population
larger than the cap. When it is true, count == cap is a lower bound.
Fields
count: u64cap: u64saturated: boolTrait Implementations
Sourceimpl Clone for BoundedCount
impl Clone for BoundedCount
impl Copy for BoundedCount
Sourceimpl Debug for BoundedCount
impl Debug for BoundedCount
Sourceimpl<'de> Deserialize<'de> for BoundedCount
impl<'de> Deserialize<'de> for BoundedCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BoundedCount
Sourceimpl PartialEq for BoundedCount
impl PartialEq for BoundedCount
Sourceimpl Serialize for BoundedCount
impl Serialize for BoundedCount
impl StructuralPartialEq for BoundedCount